@@ -7,7 +7,7 @@ class Venue(models.Model):
     venue_path = models.TextField(max_length=255)
 
     def __init__(self, *args, **kwargs):
-        self.venue_root = os.path.abspath(os.path.join(venue_path, venue_name))
+        self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
     """
         if not os.path.exists(self.venue_root):
             print 'venue does not exist at %s' % self.venue_root
